@@ -4,13 +4,13 @@ import string
 import time
 from datetime import datetime, timedelta
 
-from flask import Flask, redirect, url_for, Response, request, render_template, flash, abort
+from flask import Flask, redirect, url_for, Response, request, render_template, flash
 from flask_migrate import Migrate
 from flask_sqlalchemy import SQLAlchemy
 from flask_wtf import FlaskForm
 from wtforms import StringField, IntegerField, ValidationError, validators, DecimalField, SubmitField
 
-from flask_serialize.flask_serialize import FlaskSerializeMixin
+from flask_serialize.flask_serialize import FlaskSerialize
 from flask_serialize.form_page import FormPageMixin
 
 app = Flask("test_app")
@@ -19,6 +19,7 @@ app.config['SQLALCHEMY_TRACK_MODIFICATIONS'] = False
 app.config['SQLALCHEMY_DATABASE_URI'] = os.environ.get("SQLALCHEMY_DATABASE_URI", "sqlite:///:memory:")
 db = SQLAlchemy(app)
 migrate = Migrate(app, db)
+fs_mixin = FlaskSerialize(db)
 
 
 # =========================
@@ -76,10 +77,10 @@ def route_sub_setting_get_delete_put_post(item_id=None, user='fake'):
     return SubSetting.get_delete_put_post(item_id, user)
 
 
-@app.route('/bad_add', methods=['POST'])
-@app.route('/bad_edit/<int:item_id>', methods=['PUT', 'POST'])
-def route_bad_get_delete_put_post(item_id=None, user=None):
-    return BadModel.get_delete_put_post(item_id, user)
+@app.route('/simple_add', methods=['POST'])
+@app.route('/simple_edit/<int:item_id>', methods=['PUT', 'POST'])
+def route_simple_get_delete_put_post(item_id=None, user=None):
+    return SimpleModel.get_delete_put_post(item_id, user)
 
 
 @app.route('/setting_get_json/<int:item_id>', methods=['GET'])
@@ -191,14 +192,19 @@ def route_setting_form(item_id=None):
     new_item = Setting.form_page(item_id)
     return new_item
 
+
+@app.route('/datetest', methods=['POST'])
+@app.route('/datetest/<int:item_id>', methods=['PUT'])
+def route_datetest(item_id=None):
+    return DateTest.get_delete_put_post(item_id)
+
+
 # =========================
 # MODELS
 # =========================
 
-FlaskSerializeMixin.db = db
 
-
-class SubSetting(FlaskSerializeMixin, db.Model):
+class SubSetting(fs_mixin, db.Model):
     id = db.Column(db.Integer, primary_key=True)
     created = db.Column(db.DateTime, default=datetime.utcnow)
     sub_updated = db.Column(db.DateTime, default=datetime.utcnow)
@@ -234,13 +240,19 @@ class SubSetting(FlaskSerializeMixin, db.Model):
     timestamp_stamper = one_day_ago
 
 
-class Single(FlaskSerializeMixin, db.Model):
+class Single(fs_mixin, db.Model):
     id = db.Column(db.Integer, primary_key=True)
     wang = db.Column(db.String(120), default='wang')
     setting_id = db.Column(db.Integer, db.ForeignKey('setting.id'))
 
 
-class Setting(FlaskSerializeMixin, FormPageMixin, db.Model):
+class DateTest(fs_mixin, db.Model):
+    id = db.Column(db.Integer, primary_key=True)
+    a_date = db.Column(db.DateTime, default=datetime.utcnow)
+    update_fields = create_fields = ['a_date']
+
+
+class Setting(fs_mixin, FormPageMixin, db.Model):
     id = db.Column(db.Integer, primary_key=True)
 
     setting_type = db.Column(db.String(120), index=True, default='misc')
@@ -261,8 +273,8 @@ class Setting(FlaskSerializeMixin, FormPageMixin, db.Model):
     single = db.relationship('Single', backref='setting', uselist=False, cascade="all, delete-orphan")
 
     # serializer fields
-    update_fields = ['setting_type', 'value', 'key', 'active', 'number', 'floaty', 'scheduled', 'deci', 'lob']
-    create_fields = ['setting_type', 'value', 'key', 'active', 'user', 'floaty', 'number', 'deci', 'lob']
+    update_fields = [setting_type, 'value', 'key', 'active', 'number', 'floaty', 'scheduled', 'deci', 'lob']
+    create_fields = [setting_type, 'value', 'key', 'active', 'user', 'floaty', 'number', 'deci', 'lob']
     exclude_serialize_fields = ['created']
     exclude_json_serialize_fields = ['updated']
     relationship_fields = ['sub_settings', 'single']
@@ -328,6 +340,11 @@ class Setting(FlaskSerializeMixin, FormPageMixin, db.Model):
         if create:
             self.add_single('flang')
 
+    def fs_private_field(self, field_name):
+        if field_name.upper() == 'KEY' and self.key == 'private':
+            return True
+        return False
+
     @property
     def prop_test(self):
         return 'prop:' + self.value
@@ -367,12 +384,16 @@ class Setting(FlaskSerializeMixin, FormPageMixin, db.Model):
         return 'Setting {}'.format(self.key)
 
 
-class BadModel(FlaskSerializeMixin, db.Model):
+class SimpleModel(fs_mixin, db.Model):
     id = db.Column(db.Integer, primary_key=True)
     value = db.Column(db.String(30), default='')
 
+    @property
+    def prop(self):
+        return 'prop:' + self.value
+
     def __repr__(self):
-        return '<BadModel %r>' % (self.value)
+        return '<SimpleModel %r>' % (self.value)
 
 
 if __name__ == '__main__':
